@@ -1,10 +1,10 @@
 from __future__ import annotations
 from xml.etree.ElementTree import ElementTree, Element, tostring, fromstring, parse
-from typing import Any, List, Union
+from typing import Any, Iterable, List, Union
 import re
 
 class XmlElement():
-    def __init__(self, n: str, a: dict = {}, s: List[XmlElement] = [], t: Union[str|bool|float|int] = None, flag_as_list: bool = False):
+    def __init__(self, n: str, a: dict = {}, s: List[XmlElement] = [], t: Union[str,bool,float,int] = None, flag_as_list: bool = False):
         """Create a new XmlElement.
         
         ### Keyword arguments:
@@ -105,12 +105,24 @@ class XmlElement():
         else:
             return text
 
+
     def to_file(self, file, encoding:str = "unicode"):
         root = self.to_etree_element()
         tree = ElementTree(root)
         tree.write(file, encoding=encoding)
 
 
+    def walk(self) -> Iterable[XmlElement]:
+        """
+        Recursively yields all (sub)elements.
+        """
+        yield self
+        for e in self.subelements:
+            yield from e.walk()
+
+        return self
+
+
     @staticmethod
     def __infer_type__(value:Any, recognize_numbers:bool=True, recognize_bool:bool=True) -> Any:
         result = value
